==> charcoal-0.8.0.zip: charcoal-0.8.0/charcoal/classes/core/Config.class.php <==
<?php
/**
* ͤݻ륯饹
*
* PHP version 5
*
* @package    core
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

class Config extends Object
{
	private $_config;

	/*
	 *    󥹥ȥ饯
	 */
	public function __construct( $data = NULL )
	{
		parent::__construct();

		$this->_config = $data ? $data : array();
	}

	/*
	 *
	 */
	public function isEmptry()
	{
		return (count($this->_config) == 0);
	}

	/*
	 *¸ߤ뤫
	 */
	public function keyExists( String $key )
	{
		return isset($this->_config[ "$key" ]);
	}

	/*
	 *ɲ
	 */
	public function append( $add )
	{
		if ( $add ){
			if ( is_array( $add ) ){
				$this->_config = array_merge( $this->_config, $add );
			}
			else{
				$this->_config[] = $add;
			}
		}
	}

	/*
	 *쳬ؤΥ
	 */
	public function getKeys()
	{
		return array_keys( $this->_config );
	}

	/*
	 * ͤʸȤƼ
	 */
	public function getString( String $key, $default_value = NULL )
	{
		// ̤ʤʸ֤
		if ( !isset($this->_config[ "$key" ]) ){
			return $default_value !== NULL ? $default_value : new String('');
		}

		// ͤ
		$value = $this->_config[ "$key" ];

		// եޥåȳǧ
		if ( !is_string($value) ){
			_throw( new StringFormatException( $value, "key=[$key]" ) );
		}

		$value = s($value);

		// ֵ
		return ConfigUtil::processMacro($value);
	}

	/*
	 * ͤȤƼ
	 */
	public function getArray( String $key, $default_value = NULL )
	{
		// ̤ʤ֤
		if ( !isset($this->_config[ "$key" ]) ){
			return $default_value !== NULL ? $default_value : new Vector();
		}

		// ͤ
		$value = $this->_config[ "$key" ];

		// ޤʬ
		$array = explode( ',', $value );

		// ζ
		foreach( $array as $key => $value ){
			$array[$key] = trim($value);
		}

		// ǤĤǶʤǥե֤ͤ
		if ( count($array) == 1 && $array[0] === '' ){
			return $default_value;
		}

		// եޥåȳǧ
		if ( !is_array($array) ){
			_throw( new ArrayFormatException( $value, "key=[$key]" ) );
		}

		// ֵ
		return  v($array);
	}

	/*
	 * ͤϢȤƼ
	 */
	public function getAssoc( String $key, $default_value = NULL )
	{
		// ̤ʤǥե֤ͤ
		if ( !isset($this->_config[ "$key" ]) ){
			return $default_value !== NULL ? $default_value : new Vector();
		}

		// ͤ
		$value = $this->_config[ "$key" ];

		// եޥåȳǧ
		if ( !is_array($value) ){
			_throw( new ArrayFormatException( $value, "key=[$key]" ) );
		}

		// ֵ
		return  v($value);
	}

	/*
	 * ͤ֡ͤȤƼ
	 */
	public function getBoolean( String $key, $default_value = NULL )
	{
		// ̤ʤFALSE֤
		if ( !isset($this->_config[ "$key" ]) ){
			return $default_value !== NULL ? $default_value : new Boolean(FALSE);
		}

		// ͤ
		$value = $this->_config[ "$key" ];

		if ( is_string($value) ){
			$value = (strlen($value) > 0 );
		}

		// եޥåȳǧ
		if ( !is_bool($value) ){
			_throw( new BooleanFormatException( $value, "key=[$key]" ) );
		}

		// ֡뷿ˤֵ
		return b($value);
	}

	/*
	 * ͤͤȤƼ
	 */
	public function getInteger( String $key, $default_value = NULL )
	{
		// ̤ʤNULL֤
		if ( !isset($this->_config[ "$key" ]) ){
			return $default_value !== NULL ? $default_value : new Integer(0);
		}

		// ͤ
		$value = $this->_config[ "$key" ];

		// եޥåȳǧ
		if ( !is_integer($value) ){
			_throw( new IntegerFormatException( $value, "key=[$key]" ) );
		}

		// ˤֵ
		return (int)$value;
	}

	/*
	 *ͤ
	 */
	public function dump( String $key = NULL )
	{
		$title     = get_class($this);
		$line_end  = '<BR>';
		$indent    = '---';
		if ( $key ){
			// ΥФͤ
			$value = $this->_config[ "$key" ];
			System::dumpVar( $value, $title, $line_end, $indent );
		}
		else{
			// ٤Ƥͤ
			System::dumpArray( $this->_config, $title, $line_end, $indent );
		}
	}

}
return __FILE__;

==> charcoal-0.10.0.zip: charcoal-0.10.0/charcoal/classes/core/Config.class.php <==
<?php
/**
* ͤݻ륯饹
*
* PHP version 5
*
* @package    core
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

class Config extends Object
{
	private $_config;

	/*
	 *    󥹥ȥ饯
	 */
	public function __construct( $data = NULL )
	{
		parent::__construct();

		$this->_config = $data ? $data : array();
	}

	/*
	 *
	 */
	public function isEmptry()
	{
		return (count($this->_config) == 0);
	}

	/*
	 *¸ߤ뤫
	 */
	public function keyExists( String $key )
	{
		return isset($this->_config[ "$key" ]);
	}

	/*
	 *ɲ
	 */
	public function append( $add )
	{
		if ( $add ){
			if ( is_array( $add ) ){
				$this->_config = array_merge( $this->_config, $add );
			}
			else{
				$this->_config[] = $add;
			}
		}
	}

	/*
	 *쳬ؤΥ
	 */
	public function getKeys()
	{
		return array_keys( $this->_config );
	}

	/*
	 * ͤʸȤƼ
	 */
	public function getString( String $key, String $default_value = NULL )
	{
		// ̤ʤʸ֤
		if ( !isset($this->_config[ "$key" ]) ){
			return $default_value !== NULL ? $default_value : new String('');
		}

		// ͤ
		$value = $this->_config[ "$key" ];

		// եޥåȳǧ
		if ( !is_string($value) ){
			_throw( new StringFormatException( $value, "key=[$key]" ) );
		}

		$value = s($value);

		// ֵ
		return ConfigUtil::processMacro($value);
	}

	/*
	 * ͤȤƼ
	 */
	public function getArray( String $key, Vector $default_value = NULL )
	{
		// ̤ʤ֤
		if ( !isset($this->_config[ "$key" ]) ){
			return $default_value !== NULL ? $default_value : new Vector();
		}

		// ͤ
		$value = $this->_config[ "$key" ];

		// ޤʬ
		$array = explode( ',', $value );

		// ζ
		foreach( $array as $key => $value ){
			$array[$key] = trim($value);
		}

		// ǤĤǶʤǥե֤ͤ
		if ( count($array) == 1 && $array[0] === '' ){
			return $default_value !== NULL ? $default_value : new Vector();
		}

		// եޥåȳǧ
		if ( !is_array($array) ){
			_throw( new ArrayFormatException( $value, "key=[$key]" ) );
		}

		// ֵ
		return  v($array);
	}

	/*
	 * ͤϢȤƼ
	 */
	public function getAssoc( String $key, Vector $default_value = NULL )
	{
		// ̤ʤǥե֤ͤ
		if ( !isset($this->_config[ "$key" ]) ){
			return $default_value !== NULL ? $default_value : new Vector();
		}

		// ͤ
		$value = $this->_config[ "$key" ];

		// եޥåȳǧ
		if ( !is_array($value) && !($value instanceof Vector) ){
			_throw( new ArrayFormatException( $value, "key=[$key]" ) );
		}

		// ֵ
		return  v($value);
	}

	/*
	 * ͤ֡ͤȤƼ
	 */
	public function getBoolean( String $key, Boolean $default_value = NULL )
	{
		// ̤ʤFALSE֤
		if ( !isset($this->_config[ "$key" ]) ){
			return $default_value !== NULL ? $default_value : new Boolean(FALSE);
		}

		// ͤ
		$value = $this->_config[ "$key" ];

		if ( is_string($value) ){
			$value = (strlen($value) > 0 );
		}

		// եޥåȳǧ
		if ( !is_bool($value) ){
			_throw( new BooleanFormatException( $value, "key=[$key]" ) );
		}

		// ֡뷿ˤֵ
		return b($value);
	}

	/*
	 * ͤͤȤƼ
	 */
	public function getInteger( String $key, Integer $default_value = NULL )
	{
		// ̤ʤNULL֤
		if ( !isset($this->_config[ "$key" ]) ){
			return $default_value !== NULL ? $default_value : new Integer(0);
		}

		// ͤ
		$value = $this->_config[ "$key" ];

		// եޥåȳǧ
		if ( !is_integer($value) ){
			_throw( new IntegerFormatException( $value, "key=[$key]" ) );
		}

		// ˤֵ
		return (int)$value;
	}

	/*
	 *ͤ
	 */
	public function dump( String $key = NULL )
	{
		$title     = get_class($this);
		$line_end  = '<BR>';
		$indent    = '---';
		if ( $key ){
			// ΥФͤ
			$value = $this->_config[ "$key" ];
			System::dumpVar( $value, $title, $line_end, $indent );
		}
		else{
			// ٤Ƥͤ
			System::dumpArray( $this->_config, $title, $line_end, $indent );
		}
	}

}
return __FILE__;
